@@ -258,9 +258,7 @@ You can use \\[hexl-find-file] to visit a file in hexl-mode.
   "Edit file FILENAME in hexl-mode.
 Switch to a buffer visiting file FILENAME, creating one if none exists."
   (interactive "fFilename: ")
-  (if (or (eq system-type 'ms-dos) (eq system-type 'windows-nt))
-      (find-file-binary filename)
-    (find-file filename))
+  (find-file filename 'binary)
   (if (not (eq major-mode 'hexl-mode))
       (hexl-mode)))
 
