@@ -26,7 +26,7 @@
  
 ;;; Commentary:
 
-;; $Id: whitespace-mode.el,v 1.2 1998/09/08 05:51:45 steveb Exp $
+;; $Id: whitespace-mode.el,v 1.3 2000/10/06 09:27:59 youngs Exp $
 ;; Description:
 ;;
 ;;	This is a minor mode, which highlights whitespaces (blanks and
@@ -78,7 +78,7 @@
 ;;	`whitespace-blank-face' and `whitespace-tab-face'.
 ;;	Use the command `whitespace-show-faces' to show their values.
 ;;	In this mode only these tabs and blanks are highlighted, which are in 
-;;	the region from (point) - (window-heigh) to (point) + (window-heigh)."
+;;	the region from (point) - (window-height) to (point) + (window-height)."
 
 ;;; Code:
 
@@ -288,7 +288,7 @@ Valid values are: 'whitespace--mode and 'whitespace-incremental-mode."
 	       to))
 
 (defun whitespace-incremental-highlight (from to)
-  "Highligthts the region from FROM to TO incremental."
+  "Highlights the region from FROM to TO incremental."
   (save-excursion
     (goto-char from)
     (let ((extent (extent-at (point) nil 'whitespace-highlighted-region))
@@ -423,7 +423,7 @@ are highlighted with different faces. The faces are:
 `whitespace-blank-face' and `whitespace-tab-face'.
 Use the command `whitespace-show-faces' to show their values.
 In this mode only these tabs and blanks are highlighted, which are in 
-the region from (point) - (window-heigh) to (point) + (window-heigh)."
+the region from (point) - (window-height) to (point) + (window-height)."
   (interactive "P")
   (setq whitespace-incremental-mode
 	(if (null arg) (not whitespace-incremental-mode)
